@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class SelectProgramListWidget : public QListWidget
     Q_OBJECT
 public:
     explicit SelectProgramListWidget(QWidget *parent = nullptr);
-    ~SelectProgramListWidget();
+    ~SelectProgramListWidget() override;
 
     void setNoProgramFound(bool noProgramFound);
 
